@@ -34,9 +34,9 @@
 #define udecsizeof(t) ((CHAR_BIT * sizeof(t) / 3) + 1)
 #define sdecsizeof(t) (udecsizeof(t) + 1)
 
-extern void config_oom( void );
+extern void config_oom(void);
 
-void config_oom( void )
+void config_oom(void)
 {
 	fprintf(stderr, "out of memory\n");
 	exit(EXIT_FAILURE);
@@ -44,7 +44,7 @@ void config_oom( void )
 
 /* string manipulators */
 
-static ConfigString string_init_len( const char *s, size_t n )
+static ConfigString string_init_len(const char *s, size_t n)
 {
 	ConfigString string;
 	
@@ -73,7 +73,7 @@ static ConfigString string_init_len( const char *s, size_t n )
 	return string;
 }
 
-static void string_deinit( ConfigString *string )
+static void string_deinit(ConfigString *string)
 {
 	char is_long = CONFIG_STRING_LONG_TAG(*string);
 	
@@ -84,7 +84,7 @@ static void string_deinit( ConfigString *string )
 	}
 }
 
-static bool string_equal_len( ConfigString *string, const char *s, size_t n )
+static bool string_equal_len(ConfigString *string, const char *s, size_t n)
 {
 	const char *cstr = config_string_to_cstr(string);
 	return strncmp(cstr, s, n) == 0 && cstr[n] == '\0';
@@ -92,10 +92,10 @@ static bool string_equal_len( ConfigString *string, const char *s, size_t n )
 
 /* config manipulators */
 
-static void deinit_section( ConfigSection *section );
-static void deinit_option( ConfigOption *option );
+static void deinit_section(ConfigSection *section);
+static void deinit_option(ConfigOption *option);
 
-void config_init( Config *config )
+void config_init(Config *config)
 {
 	assert(config != NULL);
 	
@@ -103,7 +103,7 @@ void config_init( Config *config )
 	config->sections = NULL;
 }
 
-void config_deinit( Config *config )
+void config_deinit(Config *config)
 {
 	assert(config != NULL);
 	
@@ -120,7 +120,7 @@ void config_deinit( Config *config )
 
 /* config section manipulators -- internal */
 
-static void init_section( ConfigSection *section, const char *type, size_t type_len, const char *name, size_t name_len )
+static void init_section(ConfigSection *section, const char *type, size_t type_len, const char *name, size_t name_len)
 {
 	section->type = string_init_len(type, type_len);
 	section->name = string_init_len(name, name_len);
@@ -128,7 +128,7 @@ static void init_section( ConfigSection *section, const char *type, size_t type_
 	section->options = NULL;
 }
 
-static void deinit_section( ConfigSection *section )
+static void deinit_section(ConfigSection *section)
 {
 	for (unsigned int o = 0; o < section->options_count; ++o)
 	{
@@ -146,7 +146,7 @@ static void deinit_section( ConfigSection *section )
 
 /* config section accessors/manipulators -- by type, name */
 
-ConfigSection *config_add_section_len( Config *config, const char *type, size_t type_len, const char *name, size_t name_len )
+ConfigSection *config_add_section_len(Config *config, const char *type, size_t type_len, const char *name, size_t name_len)
 {
 	assert(config != NULL);
 	assert(type != NULL);
@@ -165,7 +165,7 @@ ConfigSection *config_add_section_len( Config *config, const char *type, size_t
 	return section;
 }
 
-ConfigSection *config_find_sections( Config *config, const char *type, ConfigSection **save )
+ConfigSection *config_find_sections(Config *config, const char *type, ConfigSection **save)
 {
 	assert(config != NULL);
 	assert(type != NULL);
@@ -186,7 +186,7 @@ ConfigSection *config_find_sections( Config *config, const char *type, ConfigSec
 	return section < sections_end ? section : NULL;
 }
 
-ConfigSection *config_find_section( Config *config, const char *type, const char *name )
+ConfigSection *config_find_section(Config *config, const char *type, const char *name)
 {
 	assert(config != NULL);
 	assert(type != NULL);
@@ -206,7 +206,7 @@ ConfigSection *config_find_section( Config *config, const char *type, const char
 	return NULL;
 }
 
-ConfigSection *config_find_or_add_section( Config *config, const char *type, const char *name )
+ConfigSection *config_find_or_add_section(Config *config, const char *type, const char *name)
 {
 	assert(config != NULL);
 	assert(type != NULL);
@@ -221,13 +221,13 @@ ConfigSection *config_find_or_add_section( Config *config, const char *type, con
 
 /* config option manipulators -- internal */
 
-static void init_option_value( ConfigOption *option, const char *value, size_t value_len )
+static void init_option_value(ConfigOption *option, const char *value, size_t value_len)
 {
 	option->values_count = 0;
 	option->v.value = string_init_len(value, value_len);
 }
 
-static void deinit_option_value( ConfigOption *option )
+static void deinit_option_value(ConfigOption *option)
 {
 	if (option->values_count != 0)
 	{
@@ -244,19 +244,19 @@ static void deinit_option_value( ConfigOption *option )
 	}
 }
 
-static void init_option( ConfigOption *option, const char *key, size_t key_len, const char *value, size_t value_len )
+static void init_option(ConfigOption *option, const char *key, size_t key_len, const char *value, size_t value_len)
 {
 	option->key = string_init_len(key, key_len);
 	init_option_value(option, value, value_len);
 }
 
-static void deinit_option( ConfigOption *option )
+static void deinit_option(ConfigOption *option)
 {
 	string_deinit(&option->key);
 	deinit_option_value(option);
 }
 
-static ConfigOption *append_option( ConfigSection *section, const char *key, size_t key_len, const char *value, size_t value_len )
+static ConfigOption *append_option(ConfigSection *section, const char *key, size_t key_len, const char *value, size_t value_len)
 {
 	ConfigOption *options = realloc(section->options, (section->options_count + 1) * sizeof(ConfigSection));
 	if (options == NULL)
@@ -272,7 +272,7 @@ static ConfigOption *append_option( ConfigSection *section, const char *key, siz
 	return option;
 }
 
-static ConfigOption *get_option_len( ConfigSection *section, const char *key, size_t key_len )
+static ConfigOption *get_option_len(ConfigSection *section, const char *key, size_t key_len)
 {
 	assert(section != NULL);
 	assert(key != NULL);
@@ -287,7 +287,7 @@ static ConfigOption *get_option_len( ConfigSection *section, const char *key, si
 
 /* config option accessors/manipulators -- by key */
 
-ConfigOption *config_set_option_len( ConfigSection *section, const char *key, size_t key_len, const char *value, size_t value_len )
+ConfigOption *config_set_option_len(ConfigSection *section, const char *key, size_t key_len, const char *value, size_t value_len)
 {
 	assert(section != NULL);
 	assert(key != NULL);
@@ -300,7 +300,7 @@ ConfigOption *config_set_option_len( ConfigSection *section, const char *key, si
 	return append_option(section, key, key_len, value, value_len);
 }
 
-ConfigOption *config_get_option( const ConfigSection *section, const char *key )
+ConfigOption *config_get_option(const ConfigSection *section, const char *key)
 {
 	assert(section != NULL);
 	assert(key != NULL);
@@ -313,7 +313,7 @@ ConfigOption *config_get_option( const ConfigSection *section, const char *key )
 	return NULL;
 }
 
-ConfigOption *config_get_or_set_option_len( ConfigSection *section, const char *key, size_t key_len, const char *value, size_t value_len )
+ConfigOption *config_get_or_set_option_len(ConfigSection *section, const char *key, size_t key_len, const char *value, size_t value_len)
 {
 	assert(section != NULL);
 	assert(key != NULL);
@@ -326,13 +326,13 @@ ConfigOption *config_get_or_set_option_len( ConfigSection *section, const char *
 	return append_option(section, key, key_len, value, value_len);
 }
 
-void config_set_string_option_len( ConfigSection *section, const char *key, size_t key_len, const char *value, size_t value_len )
+void config_set_string_option_len(ConfigSection *section, const char *key, size_t key_len, const char *value, size_t value_len)
 {
 	if (config_set_option_len(section, key, key_len, value, value_len) == NULL)
 		config_oom();
 }
 
-bool config_get_string_option( const ConfigSection *section, const char *key, const char **out_value )
+bool config_get_string_option(const ConfigSection *section, const char *key, const char **out_value)
 {
 	assert(section != NULL);
 	assert(key != NULL);
@@ -351,14 +351,14 @@ bool config_get_string_option( const ConfigSection *section, const char *key, co
 	return false;
 }
 
-const char *config_get_or_set_string_option( ConfigSection *section, const char *key, const char *value )
+const char *config_get_or_set_string_option(ConfigSection *section, const char *key, const char *value)
 {
 	if (!config_get_string_option(section, key, &value))
 		config_set_string_option_len(section, key, strlen(key), value, value == NULL ? 0 : strlen(value));
 	return value;
 }
 
-static const char *bool_values[][2] = 
+static const char *const bool_values[][2] = 
 {
 	{ "0", "1" },
 	{ "no", "yes" },
@@ -366,13 +366,13 @@ static const char *bool_values[][2] =
 	{ "false", "true" },
 };
 
-void config_set_bool_option( ConfigSection *section, const char *key, bool value, ConfigBoolStyle style )
+void config_set_bool_option(ConfigSection *section, const char *key, bool value, ConfigBoolStyle style)
 {
 	if (config_set_option(section, key, bool_values[style][value ? 1 : 0]) == NULL)
 		config_oom();
 }
 
-bool config_get_bool_option( const ConfigSection *section, const char *key, bool *out_value )
+bool config_get_bool_option(const ConfigSection *section, const char *key, bool *out_value)
 {
 	assert(section != NULL);
 	assert(key != NULL);
@@ -397,14 +397,14 @@ bool config_get_bool_option( const ConfigSection *section, const char *key, bool
 	return false;
 }
 
-bool config_get_or_set_bool_option( ConfigSection *section, const char *key, bool value, ConfigBoolStyle style )
+bool config_get_or_set_bool_option(ConfigSection *section, const char *key, bool value, ConfigBoolStyle style)
 {
 	if (!config_get_bool_option(section, key, &value))
 		config_set_bool_option(section, key, value, style);
 	return value;
 }
 
-void config_set_int_option( ConfigSection *section, const char *key, int value )
+void config_set_int_option(ConfigSection *section, const char *key, int value)
 {
 	assert(key != NULL);
 	
@@ -415,7 +415,7 @@ void config_set_int_option( ConfigSection *section, const char *key, int value )
 		config_oom();
 }
 
-bool config_get_int_option( const ConfigSection *section, const char *key, int *out_value )
+bool config_get_int_option(const ConfigSection *section, const char *key, int *out_value)
 {
 	assert(section != NULL);
 	assert(key != NULL);
@@ -436,14 +436,14 @@ bool config_get_int_option( const ConfigSection *section, const char *key, int *
 	return false;
 }
 
-int config_get_or_set_int_option( ConfigSection *section, const char *key, int value )
+int config_get_or_set_int_option(ConfigSection *section, const char *key, int value)
 {
 	if (!config_get_int_option(section, key, &value))
 		config_set_int_option(section, key, value);
 	return value;
 }
 
-void config_set_uint_option( ConfigSection *section, const char *key, unsigned int value )
+void config_set_uint_option(ConfigSection *section, const char *key, unsigned int value)
 {
 	assert(key != NULL);
 	
@@ -454,7 +454,7 @@ void config_set_uint_option( ConfigSection *section, const char *key, unsigned i
 		config_oom();
 }
 
-bool config_get_uint_option( const ConfigSection *section, const char *key, unsigned int *out_value )
+bool config_get_uint_option(const ConfigSection *section, const char *key, unsigned int *out_value)
 {
 	assert(section != NULL);
 	assert(key != NULL);
@@ -475,7 +475,7 @@ bool config_get_uint_option( const ConfigSection *section, const char *key, unsi
 	return false;
 }
 
-unsigned int config_get_or_set_uint_option( ConfigSection *section, const char *key, unsigned int value )
+unsigned int config_get_or_set_uint_option(ConfigSection *section, const char *key, unsigned int value)
 {
 	if (!config_get_uint_option(section, key, &value))
 		config_set_uint_option(section, key, value);
@@ -484,7 +484,7 @@ unsigned int config_get_or_set_uint_option( ConfigSection *section, const char *
 
 /* config option accessors/manipulators -- by reference */
 
-ConfigOption *config_set_value_len( ConfigOption *option, const char *value, size_t value_len )
+ConfigOption *config_set_value_len(ConfigOption *option, const char *value, size_t value_len)
 {
 	assert(option != NULL);
 	
@@ -495,7 +495,7 @@ ConfigOption *config_set_value_len( ConfigOption *option, const char *value, siz
 	return option;
 }
 
-ConfigOption *config_add_value_len( ConfigOption *option, const char *value, size_t value_len )
+ConfigOption *config_add_value_len(ConfigOption *option, const char *value, size_t value_len)
 {
 	assert(option != NULL);
 	assert(value != NULL);
@@ -528,7 +528,7 @@ ConfigOption *config_add_value_len( ConfigOption *option, const char *value, siz
 	return option;
 }
 
-ConfigOption *config_remove_value( ConfigOption *option, unsigned int i )
+ConfigOption *config_remove_value(ConfigOption *option, unsigned int i)
 {
 	assert(option != NULL);
 	
@@ -566,7 +566,7 @@ ConfigOption *config_remove_value( ConfigOption *option, unsigned int i )
 	return option;
 }
 
-const char *config_get_value( const ConfigOption *option )
+const char *config_get_value(const ConfigOption *option)
 {
 	if (option == NULL || option->values_count != 0)
 		return NULL;
@@ -576,17 +576,17 @@ const char *config_get_value( const ConfigOption *option )
 
 /* config parser */
 
-static bool is_whitespace( char c )
+static bool is_whitespace(char c)
 {
 	return c == '\t' || c == ' ';
 }
 
-static bool is_end( char c )
+static bool is_end(char c)
 {
 	return c == '\0' || c == '\n' || c == '\r';
 }
 
-static bool is_whitespace_or_end( char c )
+static bool is_whitespace_or_end(char c)
 {
 	return is_whitespace(c) || is_end(c);
 }
@@ -599,7 +599,7 @@ typedef enum
 	LIST_DIRECTIVE,
 } Directive;
 
-static Directive match_directive( const char *buffer, size_t *index )
+static Directive match_directive(const char *buffer, size_t *index)
 {
 	size_t i = *index;
 	
@@ -636,7 +636,7 @@ static Directive match_directive( const char *buffer, size_t *index )
 	return directive;
 }
 
-static bool match_nonquote_field( const char *buffer, size_t *index, size_t *length )
+static bool match_nonquote_field(const char *buffer, size_t *index, size_t *length)
 {
 	size_t i = *index;
 	
@@ -660,7 +660,7 @@ static bool match_nonquote_field( const char *buffer, size_t *index, size_t *len
 	return *length > 0;
 }
 
-static bool parse_quote_field( char *buffer, size_t *index, size_t *length )
+static bool parse_quote_field(char *buffer, size_t *index, size_t *length)
 {
 	size_t i = *index;
 	size_t o = *index;
@@ -737,7 +737,7 @@ static bool parse_quote_field( char *buffer, size_t *index, size_t *length )
 	return true;
 }
 
-static bool parse_field( char *buffer, size_t *index, size_t *start, size_t *length )
+static bool parse_field(char *buffer, size_t *index, size_t *start, size_t *length)
 {
 	size_t i = *index;
 	
@@ -765,7 +765,7 @@ static bool parse_field( char *buffer, size_t *index, size_t *start, size_t *len
 	return true;
 }
 
-bool config_parse( Config *config, FILE *file )
+bool config_parse(Config *config, FILE *file)
 {
 	assert(config != NULL);
 	assert(file != NULL);
@@ -908,7 +908,7 @@ bool config_parse( Config *config, FILE *file )
 
 /* config writer */
 
-static void write_field( const ConfigString *field, FILE *file )
+static void write_field(const ConfigString *field, FILE *file)
 {
 	fputc('\'', file);
 	
@@ -984,7 +984,7 @@ static void write_field( const ConfigString *field, FILE *file )
 	fputc('\'', file);
 }
 
-void config_write( const Config *config, FILE *file )
+void config_write(const Config *config, FILE *file)
 {
 	assert(config != NULL);
 	assert(file != NULL);
