@@ -25,12 +25,11 @@
 
 extern bool playing, songlooped;
 
-int lds_update( void );
-bool lds_load( FILE *f, unsigned int music_offset, unsigned int music_size );
-void lds_free( void );
-void lds_rewind( void );
-
-#define REFRESH 70.0f
+int lds_update(void);
+bool lds_load(FILE *f, unsigned int music_offset, unsigned int music_size);
+void lds_free(void);
+void lds_rewind(void);
+void lds_fade(Uint8 speed);
 
 /*unsigned int getorders() { return numposi; }
 unsigned int getorder() { return posplay; }
@@ -71,4 +70,3 @@ void lds_setregs(unsigned char reg, unsigned char val);
 void lds_setregs_adv(unsigned char reg, unsigned char mask, unsigned char val);
 
 #endif /* LDS_PLAY_H */
-
