@@ -99,7 +99,7 @@ JE_boolean pauseRequest, skipLevelRequest, helpRequest, nortShipRequest;
 JE_boolean yourInGameMenuRequest, inGameMenuRequest;
 
 #ifdef WITH_NETWORK
-static void packet_copy( UDPpacket *dst, UDPpacket *src )
+static void packet_copy(UDPpacket *dst, UDPpacket *src)
 {
 	void *temp = dst->data;
 	memcpy(dst, src, sizeof(*dst));
@@ -107,7 +107,7 @@ static void packet_copy( UDPpacket *dst, UDPpacket *src )
 	memcpy(dst->data, src->data, src->len);
 }
 
-static void packets_shift_up( UDPpacket **packet, int max_packets )
+static void packets_shift_up(UDPpacket **packet, int max_packets)
 {
 		if (packet[0])
 		{
@@ -120,7 +120,7 @@ static void packets_shift_up( UDPpacket **packet, int max_packets )
 		packet[max_packets - 1] = NULL;
 }
 
-static void packets_shift_down( UDPpacket **packet, int max_packets )
+static void packets_shift_down(UDPpacket **packet, int max_packets)
 {
 	if (packet[max_packets - 1])
 	{
@@ -134,14 +134,14 @@ static void packets_shift_down( UDPpacket **packet, int max_packets )
 }
 
 // prepare new packet for sending
-void network_prepare( Uint16 type )
+void network_prepare(Uint16 type)
 {
 	SDLNet_Write16(type,          &packet_out_temp->data[0]);
 	SDLNet_Write16(last_out_sync, &packet_out_temp->data[2]);
 }
 
 // send packet but don't expect acknowledgment of delivery
-static bool network_send_no_ack( int len )
+static bool network_send_no_ack(int len)
 {
 	packet_out_temp->len = len;
 
@@ -155,7 +155,7 @@ static bool network_send_no_ack( int len )
 }
 
 // send packet and place it in queue to be acknowledged
-bool network_send( int len )
+bool network_send(int len)
 {
 	bool temp = network_send_no_ack(len);
 
@@ -164,7 +164,9 @@ bool network_send( int len )
 	{
 		packet_out[i] = SDLNet_AllocPacket(NET_PACKET_SIZE);
 		packet_copy(packet_out[i], packet_out_temp);
-	} else {
+	}
+	else
+	{
 		// connection is probably bad now
 		fprintf(stderr, "warning: outbound packet queue overflow\n");
 		return false;
@@ -179,7 +181,7 @@ bool network_send( int len )
 }
 
 // send acknowledgment packet
-static int network_acknowledge( Uint16 sync )
+static int network_acknowledge(Uint16 sync)
 {
 	SDLNet_Write16(PACKET_ACKNOWLEDGE, &packet_out_temp->data[0]);
 	SDLNet_Write16(sync,               &packet_out_temp->data[2]);
@@ -189,13 +191,13 @@ static int network_acknowledge( Uint16 sync )
 }
 
 // activity lately?
-static bool network_is_alive( void )
+static bool network_is_alive(void)
 {
 	return (SDL_GetTicks() - last_in_tick < NET_TIME_OUT || SDL_GetTicks() - last_state_in_tick < NET_TIME_OUT);
 }
 
 // poll for new packets received, check that connection is alive, resend queued packets if necessary
-int network_check( void )
+int network_check(void)
 {
 	if (!net_initialized)
 		return -1;
@@ -300,7 +302,9 @@ int network_check( void )
 								if (packet_in[i] == NULL)
 									packet_in[i] = SDLNet_AllocPacket(NET_PACKET_SIZE);
 								packet_copy(packet_in[i], packet_temp);
-							} else {
+							}
+							else
+							{
 								// inbound packet queue overflow/underflow
 								// under normal circumstances, this is okay
 							}
@@ -349,7 +353,9 @@ int network_check( void )
 								{
 									packet_state_in_xor[i] = SDLNet_AllocPacket(NET_PACKET_SIZE);
 									packet_copy(packet_state_in_xor[i], packet_temp);
-								} else if (SDLNet_Read16(&packet_state_in_xor[i]->data[0]) != PACKET_STATE_XOR) {
+								}
+								else if (SDLNet_Read16(&packet_state_in_xor[i]->data[0]) != PACKET_STATE_XOR)
+								{
 									for (int j = 4; j < packet_state_in_xor[i]->len; j++)
 										packet_state_in_xor[i]->data[j] ^= packet_temp->data[j];
 									SDLNet_Write16(PACKET_STATE_XOR, &packet_state_in_xor[i]->data[0]);
@@ -391,7 +397,7 @@ int network_check( void )
 }
 
 // discard working packet, now processing next packet in queue
-bool network_update( void )
+bool network_update(void)
 {
 	if (packet_in[0])
 	{
@@ -406,19 +412,20 @@ bool network_update( void )
 }
 
 // has opponent gotten all the packets we've sent?
-bool network_is_sync( void )
+bool network_is_sync(void)
 {
 	return (queue_out_sync - last_ack_sync == 1);
 }
 
-
 // prepare new state for sending
-void network_state_prepare( void )
+void network_state_prepare(void)
 {
 	if (packet_state_out[0])
 	{
 		fprintf(stderr, "warning: state packet overwritten (previous packet remains unsent)\n");
-	} else {
+	}
+	else
+	{
 		packet_state_out[0] = SDLNet_AllocPacket(NET_PACKET_SIZE);
 		packet_state_out[0]->len = 28;
 	}
@@ -429,7 +436,7 @@ void network_state_prepare( void )
 }
 
 // send state packet, xor packet if applicable
-int network_state_send( void )
+int network_state_send(void)
 {
 	if (!SDLNet_UDP_Send(socket, 0, packet_state_out[0]))
 	{
@@ -461,12 +468,14 @@ int network_state_send( void )
 }
 
 // receive state packet, wait until received
-bool network_state_update( void )
+bool network_state_update(void)
 {
 	if (network_state_is_reset())
 	{
 		return 0;
-	} else {
+	}
+	else
+	{
 		packets_shift_up(packet_state_in, NET_PACKET_QUEUE);
 
 		packets_shift_up(packet_state_in_xor, NET_PACKET_QUEUE);
@@ -525,7 +534,9 @@ bool network_state_update( void )
 				packet_state_in_xor[x] = SDLNet_AllocPacket(NET_PACKET_SIZE);
 				packet_copy(packet_state_in_xor[x], packet_state_in[0]);
 				packet_state_in_xor[x]->status = 0;
-			} else {
+			}
+			else
+			{
 				for (int j = 4; j < packet_state_in_xor[x]->len; j++)
 					packet_state_in_xor[x]->data[j] ^= packet_state_in[0]->data[j];
 			}
@@ -538,13 +549,13 @@ bool network_state_update( void )
 }
 
 // ignore first network_delay states of level
-bool network_state_is_reset( void )
+bool network_state_is_reset(void)
 {
 	return (last_state_out_sync < network_delay);
 }
 
 // reset queues for new level
-void network_state_reset( void )
+void network_state_reset(void)
 {
 	last_state_in_sync = last_state_out_sync = 0;
 
@@ -576,10 +587,9 @@ void network_state_reset( void )
 	last_state_in_tick = SDL_GetTicks();
 }
 
-
 // attempt to punch through firewall by firing off UDP packets at the opponent
 // exchange game information
-int network_connect( void )
+int network_connect(void)
 {
 	SDLNet_ResolveHost(&ip, network_opponent_host, network_opponent_port);
 
@@ -690,9 +700,9 @@ connect_again:
 }
 
 // something has gone wrong :(
-void network_tyrian_halt( unsigned int err, bool attempt_sync )
+void network_tyrian_halt(unsigned int err, bool attempt_sync)
 {
-	const char *err_msg[] = {
+	const char *const err_msg[] = {
 		"Quitting...",
 		"Other player quit the game.",
 		"Network connection was lost.",
@@ -741,7 +751,7 @@ void network_tyrian_halt( unsigned int err, bool attempt_sync )
 	JE_tyrianHalt(5);
 }
 
-int network_init( void )
+int network_init(void)
 {
 	printf("Initializing network...\n");
 
@@ -780,7 +790,7 @@ int network_init( void )
 
 #endif
 
-void JE_clearSpecialRequests( void )
+void JE_clearSpecialRequests(void)
 {
 	pauseRequest = false;
 	inGameMenuRequest = false;
@@ -788,4 +798,3 @@ void JE_clearSpecialRequests( void )
 	helpRequest = false;
 	nortShipRequest = false;
 }
-
