@@ -196,7 +196,6 @@ JE_word curLoc; /*Current Pixel location of background 1*/
 
 JE_boolean firstGameOver, gameLoaded, enemyStillExploding;
 
-
 /* Destruction Ratio */
 JE_word totalEnemy;
 JE_word enemyKilled;
@@ -287,12 +286,10 @@ JE_real optionSatelliteRotate;
 JE_integer optionAttachmentMove;
 JE_boolean optionAttachmentLinked, optionAttachmentReturn;
 
-
 JE_byte chargeWait, chargeLevel, chargeMax, chargeGr, chargeGrWait;
 
 JE_word neat;
 
-
 /*ExplosionData*/
 explosion_type explosions[MAX_EXPLOSIONS]; /* [1..ExplosionMax] */
 JE_integer explosionFollowAmountX, explosionFollowAmountY;
@@ -324,7 +321,7 @@ JE_boolean  linkToPlayer;
 JE_word shipGr, shipGr2;
 Sprite2_array *shipGrPtr, *shipGr2ptr;
 
-void JE_getShipInfo( void )
+void JE_getShipInfo(void)
 {
 	JE_boolean extraShip, extraShip2;
 
@@ -363,7 +360,6 @@ void JE_getShipInfo( void )
 	{
 		player[i].initial_armor = player[i].armor;
 
-
 		uint temp = ((i == 0 && extraShip) ||
 		             (i == 1 && extraShip2)) ? 2 : ships[player[i].items.ship].ani;
 
@@ -380,7 +376,7 @@ void JE_getShipInfo( void )
 	}
 }
 
-JE_word JE_SGr( JE_word ship, Sprite2_array **ptr )
+JE_word JE_SGr(JE_word ship, Sprite2_array **ptr)
 {
 	const JE_word GR[15] /* [1..15] */ = {233, 157, 195, 271, 81, 0, 119, 5, 43, 81, 119, 157, 195, 233, 271};
 
@@ -391,7 +387,7 @@ JE_word JE_SGr( JE_word ship, Sprite2_array **ptr )
 	return GR[tempW-1];
 }
 
-void JE_drawOptions( void )
+void JE_drawOptions(void)
 {
 	SDL_Surface *temp_surface = VGAScreen;
 	VGAScreen = VGAScreenSeg;
@@ -416,7 +412,6 @@ void JE_drawOptions( void )
 		this_player->sidekick[i].charge = 0;
 		this_player->sidekick[i].charge_ticks = 20;
 
-
 		// draw initial sidekick HUD
 		const int y = hud_sidekick_y[twoPlayerMode ? 1 : 0][i];
 
@@ -431,7 +426,7 @@ void JE_drawOptions( void )
 	JE_drawOptionLevel();
 }
 
-void JE_drawOptionLevel( void )
+void JE_drawOptionLevel(void)
 {
 	if (twoPlayerMode)
 	{
@@ -442,7 +437,7 @@ void JE_drawOptionLevel( void )
 	}
 }
 
-void JE_tyrianHalt( JE_byte code )
+void JE_tyrianHalt(JE_byte code)
 {
 	deinit_audio();
 	deinit_video();
@@ -456,9 +451,9 @@ void JE_tyrianHalt( JE_byte code )
 	free_sprite2s(&explosionSpriteSheet);
 	free_sprite2s(&destructSpriteSheet);
 
-	for (int i = 0; i < SAMPLE_COUNT; i++)
+	for (int i = 0; i < SOUND_COUNT; i++)
 	{
-		free(digiFx[i]);
+		free(soundSamples[i]);
 	}
 
 	if (code != 9)
@@ -503,7 +498,7 @@ void JE_tyrianHalt( JE_byte code )
 	exit(code);
 }
 
-void JE_specialComplete( JE_byte playerNum, JE_byte specialType )
+void JE_specialComplete(JE_byte playerNum, JE_byte specialType)
 {
 	nextSpecialWait = 0;
 	switch (special[specialType].stype)
@@ -545,8 +540,8 @@ void JE_specialComplete( JE_byte playerNum, JE_byte specialType )
 		case 4:
 			for (temp = 0; temp < 100; temp++)
 			{
-				if (enemyAvail[temp] != 1 && enemy[temp].scoreitem
-				    && enemy[temp].evalue != 0)
+				if (enemyAvail[temp] != 1 && enemy[temp].scoreitem &&
+				    enemy[temp].evalue != 0)
 				{
 					if (player[0].x > enemy[temp].ex)
 						enemy[temp].exc++;
@@ -678,7 +673,7 @@ void JE_specialComplete( JE_byte playerNum, JE_byte specialType )
 	}
 }
 
-void JE_doSpecialShot( JE_byte playerNum, uint *armor, uint *shield )
+void JE_doSpecialShot(JE_byte playerNum, uint *armor, uint *shield)
 {
 	if (player[0].items.special > 0)
 	{
@@ -870,7 +865,7 @@ void JE_doSpecialShot( JE_byte playerNum, uint *armor, uint *shield )
 	}
 }
 
-void JE_setupExplosion( signed int x, signed int y, signed int delta_y, unsigned int type, bool fixed_position, bool follow_player )
+void JE_setupExplosion(signed int x, signed int y, signed int delta_y, unsigned int type, bool fixed_position, bool follow_player)
 {
 	const struct {
 		JE_word sprite;
@@ -943,7 +938,8 @@ void JE_setupExplosion( signed int x, signed int y, signed int delta_y, unsigned
 				{
 					explosions[i].y += 12;
 					explosions[i].x += 2;
-				} else if (type == 98)
+				}
+				else if (type == 98)
 				{
 					type = 6;
 				}
@@ -959,7 +955,7 @@ void JE_setupExplosion( signed int x, signed int y, signed int delta_y, unsigned
 	}
 }
 
-void JE_setupExplosionLarge( JE_boolean enemyGround, JE_byte exploNum, JE_integer x, JE_integer y )
+void JE_setupExplosionLarge(JE_boolean enemyGround, JE_byte exploNum, JE_integer x, JE_integer y)
 {
 	if (y >= 0)
 	{
@@ -969,7 +965,9 @@ void JE_setupExplosionLarge( JE_boolean enemyGround, JE_byte exploNum, JE_intege
 			JE_setupExplosion(x + 6, y - 14, 0,  4, false, false);
 			JE_setupExplosion(x - 6, y,      0,  3, false, false);
 			JE_setupExplosion(x + 6, y,      0,  5, false, false);
-		} else {
+		}
+		else
+		{
 			JE_setupExplosion(x - 6, y - 14, 0,  7, false, false);
 			JE_setupExplosion(x + 6, y - 14, 0,  9, false, false);
 			JE_setupExplosion(x - 6, y,      0,  8, false, false);
@@ -1006,7 +1004,7 @@ void JE_setupExplosionLarge( JE_boolean enemyGround, JE_byte exploNum, JE_intege
 	}
 }
 
-void JE_wipeShieldArmorBars( void )
+void JE_wipeShieldArmorBars(void)
 {
 	if (!twoPlayerMode || galagaMode)
 	{
@@ -1028,8 +1026,8 @@ void JE_wipeShieldArmorBars( void )
 	}
 }
 
-JE_byte JE_playerDamage( JE_byte temp,
-                         Player *this_player )
+JE_byte JE_playerDamage(JE_byte temp,
+                        Player *this_player)
 {
 	int playerDamage = 0;
 	soundQueue[7] = S_SHIELD_HIT;
@@ -1093,13 +1091,13 @@ JE_byte JE_playerDamage( JE_byte temp,
 	return playerDamage;
 }
 
-JE_word JE_portConfigs( void )
+JE_word JE_portConfigs(void)
 {
 	const uint player_index = twoPlayerMode ? 1 : 0;
 	return tempW = weaponPort[player[player_index].items.weapon[REAR_WEAPON].id].opnum;
 }
 
-void JE_drawShield( void )
+void JE_drawShield(void)
 {
 	if (twoPlayerMode && !galagaMode)
 	{
@@ -1117,7 +1115,7 @@ void JE_drawShield( void )
 	}
 }
 
-void JE_drawArmor( void )
+void JE_drawArmor(void)
 {
 	for (uint i = 0; i < COUNTOF(player); ++i)
 		if (player[i].armor > 28)
@@ -1134,7 +1132,7 @@ void JE_drawArmor( void )
 	}
 }
 
-void JE_doSP( JE_word x, JE_word y, JE_word num, JE_byte explowidth, JE_byte color ) /* superpixels */
+void JE_doSP(JE_word x, JE_word y, JE_word num, JE_byte explowidth, JE_byte color) /* superpixels */
 {
 	for (temp = 0; temp < num; temp++)
 	{
@@ -1153,7 +1151,7 @@ void JE_doSP( JE_word x, JE_word y, JE_word num, JE_byte explowidth, JE_byte col
 	}
 }
 
-void JE_drawSP( void )
+void JE_drawSP(void)
 {
 	for (int i = MAX_SUPERPIXELS; i--; )
 	{
@@ -1183,4 +1181,3 @@ void JE_drawSP( void )
 		}
 	}
 }
-
